Installing 
----------

Clone the Git repository and then use pip:

    git clone git@github.com:psiexperiment/psiopenephys
    pip install -e ./psiopenephys

This should automatically pull all dependencies you need.
